[![Version](https://img.shields.io/pypi/v/extra-datascience-tools)](https://pypi.org/project/extra-datascience-tools/)
[![Downloads](https://pepy.tech/badge/extra-datascience-tools)](https://pepy.tech/project/extra-datascience-tools)
![](https://img.shields.io/github/license/sTomerG/extra-datascience-tools)
![](https://img.shields.io/pypi/pyversions/extra-datascience-tools)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
# Python package with extra tools to use for data science.

Welcome to `extra-datascience-tools`, a Python package which offers additional tools for data scientists. These tools include or will include e.g.:
- functions
- classes
- decorators
- plots

..which are useful and often used for most data science projects, so that you don't need to rewrite the same code over again or invent it yourself. Please be aware that this package was launched in oktober 2022 and thus the current amount of features might be limited, but the features that are present can be of great use.

 Personally I'm a huge fan of well-documented code, and this package strives for quality and well-documented code over lots of under-documented features. Please visit [ReadTheDocs](https://extra-datascience-tools.readthedocs.io/en/latest/#) for this package's extensive documentation.

**[Github page](https://github.com/sTomerG/extra-datascience-tools)**

## Installation

### Using PyPi

    pip install extra-datascience-tools

Without using PyPi

    git clone https://github.com/sTomerG/extra-datascience-tools.git
    cd extra-datascience-tools
    pip install .

If problems arise make sure to have the latest version of pip:

    python3 -m pip install --upgrade pip

## Usage
    >>> import extra_ds_tools


